# src/storage
This directory contains a stub implementation that allows conversations to be offloaded to the disk. There is a stub implementation in `base.py`.

In the future, offloading to a database such as `sqlite` will be added in the `db_storage.py` file. Currently, only offloading to json is implemented in this directory.
